import pathlib
import setuptools

if __name__ == "__main__":
    version: str = "0.0.3"
    packages: list[str] = [
        "typoc",
        "typoc.cli",
        "typoc.parse",
    ]
    install_requires: list[str] = [
        "ply",
        "argparse",
        "cgen",
    ]

    root: pathlib.Path = pathlib.Path(__file__).parent
    readme: str = (root / "README.md").read_text()
    init: pathlib.Path = root / "typoc" / "__init__.py"

    old_init: str = init.read_text()
    new_init: str = old_init.replace(
        "__version__: str = None",
        f'__version__: str = "{version}"',
    )

    init.write_text(new_init)

    entry_points: dict[str, list[str]] = {
        "console_scripts": [
            "typoc = typoc.cli.main:main",
        ],
    }

    setuptools.setup(
        name="typoc",
        version=version,
        author="maDev",
        description="A PLY-based compiler for Typo implemented in Python.",
        long_description=readme,
        long_description_content_type="text/markdown",
        url="https://saahd.github.io/typoc",
        packages=packages,
        install_requires=install_requires,
        python_requires=">=3.10",
        license="MIT",
        entry_points=entry_points,
        classifiers=[
            "Programming Language :: Python :: 3.10",
            "Topic :: Software Development :: Compilers",
            "Topic :: Software Development :: Libraries :: Python Modules",
            "License :: OSI Approved :: MIT License",
        ],
    )

    init.write_text(old_init)
